
<p align="center">
  <img src="/assets/NaUKMA.png" width="350" title="hover text">
</p>

<h1 align="center">
    ua_datasets
</h1>


[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)


__ua_datasets__ is a collection of Ukrainian language datasets. Our aim is to build a benchmark for research related to 
natural language processing in Ukrainian.

This library is provided by FIdo.ai (machine learning research division of the non-profit student's organization
[FIdo](https://www.facebook.com/fido.naukma/), National University of Kyiv-Mohyla Academy) for research purposes.

## Installation
The library can be installed from PyPi in your virtual environment (e.g. venv, conda env)
```bash
pip install ua_datasets
```

## Available Datasets

#### <a href="https://github.com/fido-ai/ua-datasets/tree/main/ua_datasets/src/text_classification">Text classification </a>

#### <a href="https://github.com/fido-ai/ua-datasets/tree/main/ua_datasets/src/token_classification">Token classification </a>

#### <a href="https://github.com/fido-ai/ua-datasets/tree/main/ua_datasets/src/question_answering">Question Answering </a>


## Contribution
In case you are willing to contribute (update any part of the library, add your dataset) do not hesitate to connect through [GitHub Issue](https://github.com/fido-ai/ua-datasets/issues/new/choose). Thanks in advance for your contribution! 
Let's make the Ukrainian language even greater!

